==> GeoFIS_1.0.tar.gz: GeoFIS/R/conductivity_data.R <==
################################################################################
#
# GeoFIS R package
#
# Copyright (C) 2021 INRAE
#
# Authors:
# 	Jean-luc Lablée - INRAE
# 	Serge Guillaume - INRAE
#
# License: CeCILL v2.1
# 	https://cecill.info/licences/Licence_CeCILL_V2.1-en.html
# 	https://cecill.info/licences/Licence_CeCILL_V2.1-fr.html
#
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "https://cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights, and the successive licensors have only limited liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
#
################################################################################

#' Soil conductivity 2014 dataset
#'
#' @docType data
#'
#' @description The soil conductivity of a vine plot in year 2014
#'
#' @keywords datasets
#'
#' @usage data(conductivity_2014)
#'
#' @format [SpatialPointsDataFrame] object with 353 observations and 1 attribute:
#' \describe{
#'   \item{`conduct`}{[numeric] value, The soil conductivity}
#' }
"conductivity_2014"

#' Border dataset
#'
#' @docType data
#'
#' @description The soil conductivity border of a vine plot
#'
#' @keywords datasets
#'
#' @usage data(conductivity_border)
#'
#' @format [SpatialPolygonsDataFrame] object with 1 polygon delimiting the border of the vine plot:
#' \describe{
#'   \item{`id`}{[integer] value, The id of the polygon}
#' }
"conductivity_border"

==> GeoFIS_1.1.0.tar.gz: GeoFIS/R/conductivity_data.R <==
################################################################################
#
# GeoFIS R package
#
# Copyright (C) 2021 INRAE
#
# Authors:
# 	Jean-luc Lablée - INRAE
# 	Serge Guillaume - INRAE
#
# License: CeCILL v2.1
# 	https://cecill.info/licences/Licence_CeCILL_V2.1-en.html
# 	https://cecill.info/licences/Licence_CeCILL_V2.1-fr.html
#
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "https://cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights, and the successive licensors have only limited liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
#
################################################################################

#' Soil conductivity 2014 dataset
#'
#' @docType data
#'
#' @description The soil conductivity of a vine plot in year 2014
#'
#' @keywords datasets
#'
#' @usage data(conductivity_2014)
#'
#' @format [sp::SpatialPointsDataFrame] object with 353 observations and 1 attribute:
#' \describe{
#'   \item{`conduct`}{[numeric] value, The soil conductivity}
#' }
"conductivity_2014"

#' Border dataset
#'
#' @docType data
#'
#' @description The soil conductivity border of a vine plot
#'
#' @keywords datasets
#'
#' @usage data(conductivity_border)
#'
#' @format [sp::SpatialPolygonsDataFrame] object with 1 polygon delimiting the border of the vine plot:
#' \describe{
#'   \item{`id`}{[integer] value, The id of the polygon}
#' }
"conductivity_border"
